""" Remotsy library for python
    Copyright 2018 Jorge Cisneros jorge@remotsy.com
"""
from json import dumps, loads
from urllib2 import Request, urlopen, HTTPError, URLError
import sys


class API(object):
    """ API class for the remotsy lib core """
    def __init__(self, apiurl="https://remotsy.com/rest/"):
        self.apiurl = apiurl
        self.auth_key = None

    def post(self, url, data):
        """ Generic function to do a http post """
        req = Request(self.apiurl + url)
        req.add_header('Content-Type', 'application/json')
        if self.auth_key is not None:
            data["auth_key"] = self.auth_key
        try:
            resp = urlopen(req, dumps(data))
        except HTTPError as errobj:
            print errobj
            sys.exit(-1)
        except URLError as errobj:
            print errobj
            sys.exit(-2)
        else:
            body = loads(resp.read())
            return  body

    def login(self, username, password):
        """ Function to do the login and return a auth token """
        data = {"username": username,
                "password": password}

        self.auth_key = None
        ret = self.post("session/login", data)
        if ret["status"] == "success":
            self.auth_key = ret["data"]["auth_key"]
        return self.auth_key

    def list_controls(self):
        """ Function to get the list of the remotsy controls """
        ret = self.post("controls/list", {})
        if ret["status"] == "success":
            return ret["data"]["controls"]
        return None

    def list_buttons(self, idctl):
        """ Function to get the list of the button of a control """
        ret = self.post("controls/get_buttons_control", {"id_control": idctl})
        if ret["status"] == "success":
            return ret["data"]["buttons"]
        return None

    def list_routines(self):
        """ Function to get the list of the routines """
        ret = self.post("routines/list", {})
        if ret["status"] == "success":
            return ret["data"]["routines"]
        return None

    def play_routine(self, idrt):
        """ Function to play a routine via the Id """
        ret = self.post("routines/play_routine", {"idroutine": idrt})
        return ret["status"] == "success"

    def blast(self, iddev, idbto, ntime=1):
        """ Function to blast infrared code via remotsy """
        ret = self.post("codes/blast", {"id_dev": iddev, "code": idbto, "ntime": ntime})
        return ret["status"] == "success"

    def blink_led(self, iddev):
        """ Function to blink the led via the id_dev """
        ret = self.post("devices/blink", {"id_dev": iddev})
        return ret["status"] == "success"

    def update_firmware(self, iddev):
        """ Function to update Remotsy's firmware"""
        ret = self.post("devices/updatefirmware", {"id_dev": iddev})
        return ret["status"] == "success"
        


#!/bin/env python2
""" Example code of how to use the Remotsy Lib """
from argparse import ArgumentParser
from sys import argv
from remotsylib.api import API


if __name__ == "__main__":
    parser = ArgumentParser()
    parser.add_argument("-u", "--username", action="store", type=str, required=True)
    parser.add_argument("-p", "--password", action="store", type=str, required=True)
    args = parser.parse_args(argv[1:])

    client = API()

    #Do the login and get the token
    token = client.login(args.username, args.password)
    print "API Token", token

    #Get the list of the controls
    lst_ctl = client.list_controls()
    for ctl in lst_ctl:
        print "id %s Name %s" % (ctl["_id"], ctl['name'])

    #get the list of the available buttons for the first control
    lst_bto = client.list_buttons(lst_ctl[1]["_id"])
    for bto in lst_bto:
        if bto["key"] == "POWER OFF": #Get the Id of the POWER OFF
            print "id %s Key %s" % (bto["_id"], bto["key"])

            #Do the infrared blast using the IDDEV of the first control
            #and the id of the POWER OFF
            client.blast(lst_ctl[1]["iddev"], bto["_id"])



# Always prefer setuptools over distutils
from setuptools import setup, find_packages
# To use a consistent encoding
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, 'README.rst'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='remotsylib',
    version='0.0.1',
    description='A Remotsy lib for use the Restfull API',
    long_description=long_description,
    url='https://github.com/jorgecis/remotsylib',
    author='Jorge Cisneros',
    author_email='jorge@remotsy.com', 
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
    ],
    keywords='Remotsy infrared remote control smarthome',
    packages=find_packages(exclude=['contrib', 'docs', 'tests']), 

    #install_requires=['peppercorn'],  # Optional
    #extras_require={  # Optional
    #    'dev': ['check-manifest'],
    #    'test': ['coverage'],
    #},
)
